@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration into rhythmic phrases
 
-our $VERSION = '0.0504';
+our $VERSION = '0.0505';
 
 use Moo;
 use strictures 2;
@@ -151,7 +151,7 @@ Music::Duration::Partition - Partition a musical duration into rhythmic phrases
 
 =head1 VERSION
 
-version 0.0504
+version 0.0505
 
 =head1 SYNOPSIS
 
@@ -189,7 +189,7 @@ version 0.0504
 
 C<Music::Duration::Partition> partitions a musical duration into
 rhythmic phrases, given by the B<size>, into smaller durations drawn
-from the B<pool> of possible durations.
+from the B<pool> of possibly weighted durations.
 
 =head1 ATTRIBUTES
 
@@ -197,9 +197,9 @@ from the B<pool> of possible durations.
 
   $durations = $mdp->durations;
 
-A hash reference of C<%MIDI::Simple::Length> (keyed by duration name).
+A hash reference of duration lengths (keyed by duration name).
 
-Default: C<%MIDI::Simple::Length>
+Default: C<\%MIDI::Simple::Length>
 
 =head2 size
 
@@ -238,7 +238,8 @@ Default: Random item from B<pool>
 
 Specification of the frequency of pool item selection.
 
-The number of weights must equal number of pool entries.
+The number of weights must equal the number of pool entries.  The
+weights do not have to sum to 1 and can be any relative numbers.
 
 Default: Equal probability for each pool entry
 
